'use strict';
const Client = require('../index');
const sinon = require('sinon');
const chai = require('chai');
const expect = chai.expect;

describe('upx client test', function() {
  describe('User Client', function() {
    let user = Client.userClient('test');
    let stub;
    afterEach(function() {
      stub.restore();
    });

    describe('#login()', function() {
      it('should login success', function(done) {
        stub = sinon.stub(user.oauthclient, 'login');
        stub.returns({
          oauth: {
            accessToken: 'a',
            refreshToken: '1'
          }
        });
        user.login('x', 'x').then((oauth)=> {
          expect(oauth).to.have.property('accessToken').with.a('string');
          expect(oauth).to.have.property('refreshToken').with.a('string');
          done();
        }).catch((e)=> {
          done(e);
        });
      });

      it('should login error', function(done) {
        stub = sinon.stub(user.oauthclient, 'login');
        stub.throws({
          name: 'BucOAuthRequestError'
        });
        user.login('x', 'x').then((oauth)=> {
          done(oauth);
        }).catch((e)=> {
          expect(e).to.have.property('name').equal('BucOAuthRequestError');
          done();
        });
      });
    });
  });

  describe('Upx Client', function() {
    let upx = Client.upxClient('daily');
    it('should request assets all', function() {
      return upx.request('assetsService.allVersion',[]).then((data)=>{
        console.log(data);
        return data;
      });
    });

    it('should check zebra component', function() {
      return upx.request('zebraComponentService.getComponentByName',['xx','tb']).then((data)=>{
        console.log(data);
        return data;
      });
    });

    it('test login', function() {
      let userClient = Client.userClient('test'/*,{你自己的buc conf 或则用upx的}**/);

      return userClient.login('username', 'password')
        .then((oauth)=> {
          return userClient;
        })
        .then((user)=> {
          return userClient.getTicket();
        })
        .then(ticket=>{
          return userClient.getUserType(ticket);
        })
        .then(userType=>{
          console.log('当前用户是外包吗?', userClient.isWB(userType));
        });
    });

  });
});